<?php
/**
 * Users library
 *
 * This file contains the resources which are used to interact with
 * and perform operations on the users. It provides some helper methods
 * which are then executed by {@link Database_Record}.
 *
 * @package Database
 * @author  Alessandro Desantis <desa.alessandro@gmail.com>
 */

/**
 * Users class
 *
 * Provides the helper methods.
 *
 * @package Database
 * @author  Alessandro Desantis <desa.alessandro@gmail.com>
 */
class User extends Database_Record
{
    /**
     * Loads the record's data from the database.
     *
     * @param string Users' table column
     * @param mixed  Column's value
     *
     * @return User
     * @access public
     */
    public function __construct($column, $value)
    {
        parent::__construct('users', $column, $value);
    }

    /**
     * Sets the user's name.
     *
     * @param string New name
     *
     * @return string
     * @access protected
     */
    protected function setName($new_name)
    {
        echo "<pre>Setting user's name to '{$new_name}'.</pre>";
        return $new_name;
    }

    /**
     * Gets the user's name.
     *
     * @param string User's raw name
     *
     * @return string
     * @access protected
     */
    protected function getName($raw_name)
    {
        echo "<pre>Getting the user's name: '{$raw_name}'.</pre>";
        return $raw_name;
    }

    /**
     * Sets the user's surname.
     *
     * @param string New surname
     *
     * @return string
     * @access protected
     */
    protected function setSurname($new_surname)
    {
        echo "<pre>Setting user's surname to '{$new_surname}'.</pre>";
        return $new_surname;
    }

    /**
     * Gets the user's surname.
     *
     * @param string User's raw surname.
     *
     * @return string
     * @access protected
     */
    protected function getSurname($raw_surname)
    {
        echo "<pre>Getting the user's surname: '{$raw_surname}'.</pre>";
        return $raw_surname;
    }
}
?>
