<?php
/**
 * Advanced example
 *
 * This example is a little bit more complicated: we use a helper
 * class here which is defined in the file {@link User.php}.
 *
 * @package Database
 * @author  Alessandro Desantis <desa.alessandro@gmail.com>
 */

/**
 * Includes the class.
 */
require 'Database.php';

/**
 * Includes the helper class. This is very important, because the
 * {@link Database_Record} class won't look for the helper class'
 * file (however this feature will be implemented in the future).
 */
require 'User.php';

/**
 * Sets the database connection data.
 */
Database::setConnectionData(array(
    'dsn'  => 'mysql:host=localhost;dbname=test',
    'user' => 'root',
    'pass' => 'example',
));

/**
 * Istantiates the class.
 */
$db = Database::getInstance();

/**
 * Gets a {@link User} record from the database.
 */
try {
    $user = new User('id', 1);

    /**
     * You can also do it this way, however it's much less comfortable.
     */
    // $user = $db->getRecord('users', 'id', 1);
}
catch (DatabaseException $e) {
    die($e->getMessage());
}

/**
 * We show the record's data.
 */
echo '<pre>';
print_r($user->getData());
echo '</pre>';

/**
 * Edits some of the fields. The helper methods will
 * be applied in this case.
 */
$user->name    = 'Mario';
$user->surname = 'Rossi';

/**
 * You can also do it this way.
 */
$user['name']    = 'Mario';
$user['surname'] = 'Rossi';

/**
 * Saves the data.
 */
$user->commit();

/**
 * Shows the record's new data.
 */
echo '<pre>';
print_r($user->getData());
echo '</pre>';

/**
 * Resumes the initial situation.
 */
$user->name    = 'Faccetta';
$user->surname = 'Nera';

/**
 * Saves the data.
 */
$user->commit();
?>
